@@ -31,7 +31,7 @@ from .mappings import copy_to_model_parallel_region
 from .mappings import gather_from_model_parallel_region
 from .mappings import reduce_from_model_parallel_region
 from .mappings import scatter_to_model_parallel_region
-from .utils import divide
+from .utils import divide, unscaled_init_method
 from .utils import VocabUtility
 
 
@@ -53,7 +53,8 @@ def _initialize_affine_weight(weight, output_size, input_size,
     # Initialize master weight
     master_weight = torch.empty(output_size, input_size,
                                 dtype=weight.dtype,
-                                requires_grad=False)
+                                requires_grad=False,
+                                device=weight.device)
     init_method(master_weight, module=module, name=name)
 
     # Split and copy
@@ -80,8 +81,7 @@ class VocabParallelEmbedding(torch.nn.Module):
         embedding_dim: size of hidden state.
         init_method: method to initialize weights.
     """
-    def __init__(self, num_embeddings, embedding_dim,
-                 init_method=init.xavier_normal_):
+    def __init__(self, num_embeddings, embedding_dim, params_dtype=torch.float, init_method=unscaled_init_method(0.02), skip_init=False, device=torch.device('cpu')):
         super(VocabParallelEmbedding, self).__init__()
         # Keep the input dimensions.
         self.num_embeddings = num_embeddings
@@ -102,13 +102,15 @@ class VocabParallelEmbedding(torch.nn.Module):
                                             self.vocab_start_index
 
         # Allocate weights.
-        self.weight = Parameter(torch.Tensor(self.num_embeddings_per_partition,
-                                             self.embedding_dim))
+        self.weight = Parameter(torch.empty(self.num_embeddings_per_partition,
+                                             self.embedding_dim, dtype=params_dtype,
+                                             device=device))
         self.weight.model_parallel = True
         # And initialize.
-        _initialize_affine_weight(
-            self.weight, self.num_embeddings, self.embedding_dim,
-            self.num_embeddings_per_partition, 0, init_method)
+        if not skip_init:
+            _initialize_affine_weight(
+                self.weight, self.num_embeddings, self.embedding_dim,
+                self.num_embeddings_per_partition, 0, init_method)
 
     def forward(self, input_):
         # Build the mask.
@@ -139,9 +141,7 @@ class ParallelEmbedding(torch.nn.Module):
         embedding_dim: size of hidden state.
         init_method: method to initialize weights.
     """
-    def __init__(self, num_embeddings, embedding_dim,
-                 init_method=init.xavier_normal_,
-                 keep_master_weight_for_test=False):
+    def __init__(self, num_embeddings, embedding_dim, params_dtype=torch.float, init_method=unscaled_init_method(0.02),keep_master_weight_for_test=False, skip_init=False, device=torch.device('cpu')):
         super(ParallelEmbedding, self).__init__()
         # Keep the input dimensions.
         self.num_embeddings = num_embeddings
@@ -159,14 +159,16 @@ class ParallelEmbedding(torch.nn.Module):
                                                   world_size)
 
         # Allocate weights.
-        self.weight = Parameter(torch.Tensor(self.num_embeddings,
-                                             self.embedding_dim_per_partition))
+        self.weight = Parameter(torch.empty(self.num_embeddings,
+                                             self.embedding_dim_per_partition, dtype=params_dtype,
+                                             device=device))
         self.weight.model_parallel = True
         # And initialize.
-        _initialize_affine_weight(
-            self.weight, self.num_embeddings, self.embedding_dim,
-            self.embedding_dim_per_partition, 1, init_method,
-            stride=1, return_master_weight=False)
+        if not skip_init:
+            _initialize_affine_weight(
+                self.weight, self.num_embeddings, self.embedding_dim,
+                self.embedding_dim_per_partition, 1, init_method,
+                stride=1, return_master_weight=False)
 
     def forward(self, input_):
         input_parallel = copy_to_model_parallel_region(input_)
@@ -199,8 +201,8 @@ class ColumnParallelLinear(torch.nn.Module):
                                      used for initialization.
     """
     def __init__(self, input_size, output_size, bias=True, gather_output=True,
-                 init_method=init.xavier_normal_, stride=1,
-                 keep_master_weight_for_test=False, module=None, name=None):
+                 init_method=unscaled_init_method(0.02), stride=1,
+                 keep_master_weight_for_test=False, params_dtype=torch.float, module=None, name=None, skip_init=False, device=torch.device('cpu')):
         super(ColumnParallelLinear, self).__init__()
 
         # Keep input parameters
@@ -214,11 +216,12 @@ class ColumnParallelLinear(torch.nn.Module):
         # Parameters.
         # Note: torch.nn.functional.linear performs XA^T + b and as a result
         # we allocate the transpose.
-        self.weight = Parameter(torch.Tensor(self.output_size_per_partition,
-                                             self.input_size))
+        self.weight = Parameter(torch.empty(self.output_size_per_partition,
+                                             self.input_size, dtype=params_dtype,
+                                             device=device))
         self.weight.model_parallel = True
         if bias:
-            self.bias = Parameter(torch.Tensor(self.output_size_per_partition))
+            self.bias = Parameter(torch.empty(self.output_size_per_partition,dtype=params_dtype, device=device))
             self.bias.model_parallel = True
             # Always initialize bias to zero.
             with torch.no_grad():
@@ -227,10 +230,11 @@ class ColumnParallelLinear(torch.nn.Module):
             self.register_parameter('bias', None)
 
         # Initialize weight.
-        self.master_weight = _initialize_affine_weight(
-            self.weight, self.output_size, self.input_size,
-            self.output_size_per_partition, 0, init_method,
-            stride=stride, return_master_weight=keep_master_weight_for_test, module=module, name=name)
+        if not skip_init:
+            self.master_weight = _initialize_affine_weight(
+                self.weight, self.output_size, self.input_size,
+                self.output_size_per_partition, 0, init_method,
+                stride=stride, return_master_weight=keep_master_weight_for_test, module=module, name=name)
 
     def forward(self, input_):
         # Set up backprop all-reduce.
@@ -273,8 +277,8 @@ class RowParallelLinear(torch.nn.Module):
     """
     def __init__(self, input_size, output_size, bias=True,
                  input_is_parallel=False,
-                 init_method=init.xavier_normal_, stride=1,
-                 keep_master_weight_for_test=False, module=None, name=None):
+                 init_method=unscaled_init_method(0.02), stride=1,
+                 keep_master_weight_for_test=False, params_dtype=torch.float, module=None, name=None, skip_init=False, device=torch.device('cpu')):
         super(RowParallelLinear, self).__init__()
 
         # Keep input parameters
@@ -288,11 +292,11 @@ class RowParallelLinear(torch.nn.Module):
         # Parameters.
         # Note: torch.nn.functional.linear performs XA^T + b and as a result
         # we allocate the transpose.
-        self.weight = Parameter(torch.Tensor(self.output_size,
-                                             self.input_size_per_partition))
+        self.weight = Parameter(torch.empty(self.output_size,
+                                             self.input_size_per_partition, dtype=params_dtype, device=device))
         self.weight.model_parallel = True
         if bias:
-            self.bias = Parameter(torch.Tensor(self.output_size))
+            self.bias = Parameter(torch.empty(self.output_size, dtype=params_dtype, device=device))
             # Always initialize bias to zero.
             with torch.no_grad():
                 self.bias.zero_()
@@ -300,10 +304,11 @@ class RowParallelLinear(torch.nn.Module):
             self.register_parameter('bias', None)
 
         # Initialize weight.
-        self.master_weight = _initialize_affine_weight(
-            self.weight, self.output_size, self.input_size,
-            self.input_size_per_partition, 1, init_method,
-            stride=stride, return_master_weight=keep_master_weight_for_test, module=module, name=name)
+        if not skip_init:
+            self.master_weight = _initialize_affine_weight(
+                self.weight, self.output_size, self.input_size,
+                self.input_size_per_partition, 1, init_method,
+                stride=stride, return_master_weight=keep_master_weight_for_test, module=module, name=name)
 
     def forward(self, input_):
         # Set up backprop all-reduce.
